#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-pool
version:              0.5.2
visibility:           public
id:                   hasql-pool-0.5.2-3uW7UuEJL01DXOhE0HZdVG
key:                  hasql-pool-0.5.2-3uW7UuEJL01DXOhE0HZdVG
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool 
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  f2f8b8f6fceb9ba5135934e1f06fd731
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hasql-pool-0.5.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hasql-pool-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hasql-pool-0.5.2
hs-libraries:         HShasql-pool-0.5.2-3uW7UuEJL01DXOhE0HZdVG
depends:
    base-prelude-1.4-6gvPEnwZlZz39pkAigtkjO
    hasql-1.4.5.1-8AHTB1S21Q1IJZf9AL7OcY
    resource-pool-0.2.3.2-HuMDXx2LvNiFKUxNwBNmWZ time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

